import * as React from 'react';
import * as cx from 'classnames';
import { tokenize } from 'illuminate-js';
import { TokenElement } from './Token';
export const languages = new Map();
export class Illuminate extends React.PureComponent {
    /**
     * Add a language definition to a react-illuminate.
     * You can add same definition multiple times with different names
     *
     * @param name  The name of the language being added.
     *              This name will be used by `highlight` function.
     * @param def   The language `Definition` to be added.
     *
     * @example
     * import { Illuminate } from 'react-illuminate';
     * import { javascript } from 'illuminate-js/lib/languages';
     *
     * Illuminate.addLanguage('javascript', javascript);
     * Illuminate.addLanguage('js', javascript);
     */
    static addLanguage(name, def) {
        languages.set(name, def);
    }
    /**
     * Returns the language definition which was added using `Illuminate.addLanguage`.
     * Returns the `Definition` if found, else returns `undefined`.
     *
     * @param name The name of the language definition
     *
     * @example
     * import { Illuminate } from 'react-illuminate';
     * import { javascript } from 'illuminate-js/lib/languages';
     *
     * Illuminate.addLanguage('javascript', javascript);
     * Illuminate.addLanguage('js', javascript);
     *
     * Illuminate.getLanguage('js'); // returns javascript definition
     */
    static getLanguage(name) {
        return languages.get(name);
    }
    /**
     * Delete the language definition which was added using `Illuminate.addLanguage`.
     *
     * @param name The name of the language definition
     *
     *
     * @example
     * import { Illuminate } from 'react-illuminate';
     * import { javascript } from 'illuminate-js/lib/languages';
     *
     * Illuminate.addLanguage('javascript', javascript);
     * Illuminate.addLanguage('js', javascript);
     *
     * Illuminate.getLanguage('js'); // returns javascript definition
     */
    static deleteLanguage(name) {
        languages.delete(name);
    }
    renderLineNumbers(code) {
        const match = code.match(/\n(?!$)/g);
        const linesNum = match ? match.length + 1 : 1;
        let lines = [];
        for (let i = 0; i < linesNum; i++) {
            lines.push(React.createElement("span", { key: `line-${i}`, className: "line-number" }));
        }
        return React.createElement("span", { className: "line-numbers-rows" }, lines);
    }
    render() {
        const { lang, children } = this.props;
        let token = children;
        const grammar = Illuminate.getLanguage(lang || '');
        if (!grammar) {
            return children;
        }
        token = tokenize(children, grammar);
        const className = cx(`language-${lang}`, {
            'line-numbers': this.props.lineNumbers,
            'show-language': this.props.showLanguage
        });
        return (React.createElement("pre", { className: className },
            React.createElement("code", null,
                this.props.showLanguage && React.createElement("span", { className: "show-language--lang" }, lang),
                React.createElement(TokenElement, { customClasses: this.props.customClasses, token: token }),
                this.props.lineNumbers && this.renderLineNumbers(children))));
    }
}
